Learn R Programming

colors3d (version 1.0.1)

colors3d-package: colors3d: Generate 2D and 3D Color Palettes

Description

Generate multivariate color palettes to represent two-dimensional or three-dimensional data in graphics (in contrast to standard color palettes that represent just one variable). You tell 'colors3d' how to map color space onto your data, and it gives you a color for each data point. You can then use these colors to make plots in base 'R', 'ggplot2', or other graphics frameworks.

Arguments

Author

Maintainer: Matthew Kling mattkling@berkeley.edu [copyright holder]

See Also